@@ -6,13 +6,17 @@ from aiomisc import threaded
 from .base import CGroupTask
 from .memory import memory_collector
 from .blkio import blkio_collector
+from .cpu import cpu_collector
 
 log = logging.getLogger(__name__)
 
-HANDLER_REGISTRY = MappingProxyType({
-    "memory": memory_collector,
-    "blkio": blkio_collector,
-})
+HANDLER_REGISTRY = MappingProxyType(
+    {
+        "memory": memory_collector,
+        "blkio": blkio_collector,
+        "cpu,cpuacct": cpu_collector,
+    }
+)
 
 
 @threaded
